### 最新特性

----

1. 支持**对话框弹出**和**单页面**两种展示方式

   1. 对话框弹出：可在对应页面弹出对话框展示版本日志更新内容，避免页面跳转，需要在页面进行简单配置，引入相关资源文件并进行相关后端配置。
   2. 单页面：版本日志会跳转到新页面展示，可以避免对已有页面造成影响，只需进行后端配置。提供两种风格的单页面可选：
      * 对话框风格的单页面，适合简单版本日志。
      * 仿gitbook风格的单页面，字号会大一点，适合复杂版本日志。

2. 支持用户新版本日志通知

   当网站发布新版本并更新版本日志后，如果用户没有看过最新版本日志，网站会先跳转到版本日志页面，帮助用户了解新版本特性和功能。

3. 重新设计并支持更多配置